# Using the cribl-utilities-cli
## Install instructions
- `brew install pipx`
- `pipx install cribl-utilities-cli`
- `cribl-utilities-cli --help`

## Notes on usage
- before running the CLI make sure that your credentials are included in the same folder that you are running the CLI in. The credentials must be in a `.env` file. For an example of what this must look like run `cribl-utilities-cli example-env`